@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2019, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2020, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -185,8 +185,10 @@
 
 /** Field will not be loaded in secondary engine. */
 #define NOT_SECONDARY_FLAG (1 << 29)
+/** Field is explicitly marked as invisible by the user. */
+#define FIELD_IS_INVISIBLE (1 << 30)
 
-#define CLUSTERING_FLAG (1U << 30)
+#define CLUSTERING_FLAG (1 << 31)
 
 /** @}*/
 
@@ -212,9 +214,14 @@
 #define REFRESH_HOSTS 8    /**< Flush host cache, FLUSH HOSTS */
 #define REFRESH_STATUS 16  /**< Flush status variables, FLUSH STATUS */
 #define REFRESH_THREADS 32 /**< Flush thread cache */
-#define REFRESH_SLAVE                         \
-  64 /**< Reset master info and restart slave \
-        thread, RESET SLAVE */
+#define REFRESH_REPLICA                         \
+  64 /**< Reset master info and restart replica \
+        thread, RESET REPLICA */
+#define REFRESH_SLAVE                                        \
+  REFRESH_REPLICA /**< Reset master info and restart replica \
+        thread, RESET REPLICA. This is deprecated,           \
+        use REFRESH_REPLICA instead. */
+
 #define REFRESH_MASTER                                                 \
   128                            /**< Remove all bin logs in the index \
                                     and truncate the index, RESET MASTER */
@@ -682,15 +689,6 @@ static const int PURGE_BITMAPS_TO_LSN = 1;
 */
 #define CLIENT_DEPRECATE_EOF (1UL << 24)
 
-/**
-  Verify server certificate.
-
-  Client only flag.
-
-  @deprecated in favor of --ssl-mode.
-*/
-#define CLIENT_SSL_VERIFY_SERVER_CERT (1UL << 30)
-
 /**
   The client can handle optional metadata information in the resultset.
 */
@@ -715,11 +713,39 @@ static const int PURGE_BITMAPS_TO_LSN = 1;
 */
 #define CLIENT_ZSTD_COMPRESSION_ALGORITHM (1UL << 26)
 
+/**
+  Support optional extension for query parameters into the @ref
+  page_protocol_com_query and @ref page_protocol_com_stmt_execute packets.
+
+  Server
+  ------
+
+  Expects an optional part containing the query parameter set(s). Executes the
+  query for each set of parameters or returns an error if more than 1 set of
+  parameters is sent and the server can't execute it.
+
+  Client
+  ------
+
+  Can send the optional part containing the query parameter set(s).
+*/
+#define CLIENT_QUERY_ATTRIBUTES (1UL << 27)
+
 /**
   This flag will be reserved to extend the 32bit capabilities structure to
   64bits.
 */
 #define CLIENT_CAPABILITY_EXTENSION (1UL << 29)
+
+/**
+  Verify server certificate.
+
+  Client only flag.
+
+  @deprecated in favor of --ssl-mode.
+*/
+#define CLIENT_SSL_VERIFY_SERVER_CERT (1UL << 30)
+
 /**
   Don't reset the options after an unsuccessful connect
 
@@ -748,7 +774,7 @@ static const int PURGE_BITMAPS_TO_LSN = 1;
    CLIENT_PLUGIN_AUTH_LENENC_CLIENT_DATA |                                     \
    CLIENT_CAN_HANDLE_EXPIRED_PASSWORDS | CLIENT_SESSION_TRACK |                \
    CLIENT_DEPRECATE_EOF | CLIENT_OPTIONAL_RESULTSET_METADATA |                 \
-   CLIENT_ZSTD_COMPRESSION_ALGORITHM)
+   CLIENT_ZSTD_COMPRESSION_ALGORITHM | CLIENT_QUERY_ATTRIBUTES)
 
 /**
   Switch off from ::CLIENT_ALL_FLAGS the flags that are optional and
@@ -852,13 +878,15 @@ struct Vio;
 #define MYSQL_VIO struct Vio *
 #endif
 
-#define MAX_TINYINT_WIDTH 3     /**< Max width for a TINY w.o. sign */
-#define MAX_SMALLINT_WIDTH 5    /**< Max width for a SHORT w.o. sign */
-#define MAX_MEDIUMINT_WIDTH 8   /**< Max width for a INT24 w.o. sign */
-#define MAX_INT_WIDTH 10        /**< Max width for a LONG w.o. sign */
-#define MAX_BIGINT_WIDTH 20     /**< Max width for a LONGLONG */
-#define MAX_CHAR_WIDTH 255      /**< Max length for a CHAR colum */
-#define MAX_BLOB_WIDTH 16777216 /**< Default width for blob */
+#define MAX_TINYINT_WIDTH 3   /**< Max width for a TINY w.o. sign */
+#define MAX_SMALLINT_WIDTH 5  /**< Max width for a SHORT w.o. sign */
+#define MAX_MEDIUMINT_WIDTH 8 /**< Max width for a INT24 w.o. sign */
+#define MAX_INT_WIDTH 10      /**< Max width for a LONG w.o. sign */
+#define MAX_BIGINT_WIDTH 20   /**< Max width for a LONGLONG */
+/// Max width for a CHAR column, in number of characters
+#define MAX_CHAR_WIDTH 255
+/// Default width for blob in bytes @todo - align this with sizes from field.h
+#define MAX_BLOB_WIDTH 16777216
 
 typedef struct NET {
   MYSQL_VIO vio;
@@ -1023,7 +1051,7 @@ bool my_net_init(struct NET *net, MYSQL_VIO vio);
 void my_net_local_init(struct NET *net);
 void net_end(struct NET *net);
 void net_clear(struct NET *net, bool check_buffer);
-void net_claim_memory_ownership(struct NET *net);
+void net_claim_memory_ownership(struct NET *net, bool claim);
 bool net_realloc(struct NET *net, size_t length);
 bool net_flush(struct NET *net);
 bool my_net_write(struct NET *net, const unsigned char *packet, size_t len);
@@ -1033,6 +1061,8 @@ bool net_write_command(struct NET *net, unsigned char command,
 bool net_write_packet(struct NET *net, const unsigned char *packet,
                       size_t length);
 unsigned long my_net_read(struct NET *net);
+bool my_net_shrink_buffer(NET *net, unsigned long min_buf_size,
+                          unsigned long *max_interval_packet);
 void my_net_set_write_timeout(struct NET *net, unsigned int timeout);
 void my_net_set_read_timeout(struct NET *net, unsigned int timeout);
 void my_net_set_retry_count(struct NET *net, unsigned int retry_count);
@@ -1043,7 +1073,7 @@ struct rand_struct {
 };
 
 /* Include the types here so existing UDFs can keep compiling */
-#include <mysql/udf_registration_types.h>
+#include "mysql/udf_registration_types.h"
 
 /**
   @addtogroup group_cs_compresson_constants Constants when using compression
